<?php
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Shortcode class for rendering in front end
 */
if ( ! class_exists( 'ATTEST_LMS_CONGRATS_SHORTCODE' ) ) {

	class ATTEST_LMS_CONGRATS_SHORTCODE {

		protected $query;
		protected $number_courses;
		protected $courses_permalink;

		public function __construct() {

			$courses_post_id = get_option('attest_template_courses');
			$this->courses_permalink = get_permalink($courses_post_id);

			add_shortcode( 'wp_attest_congrats', array( $this, 'courses_cb' ) );
		}


		public function courses_cb($atts) {

			$data = shortcode_atts( array(
								'text' => __('Congratulations for finishing', 'attest'),
							), $atts );

			return $this->congrats_html($data);
		}


		/**
		 * Shortcode Display
		 */
		public function congrats_html($data) {

			$course = (isset($_GET['course']) ? $_GET['course'] : false);
			$student = get_current_user_id();
			$checked = $this->course_check($course, $student);

			$body = '<div class="container text-center">
				<div class="row">
					<div class="col-md-12">
						<h2 class="mb-3">🎉 ' . $data['text'] . '</h2>
						<a href="' . esc_url_raw(get_permalink($course)) . '">' . esc_attr(get_the_title($course)) . '</a>
						<p class="mt-5"><a class="attest-button" href="' . esc_url_raw($this->courses_permalink) . '">' . __('GO TO MY COURSES', 'attest') . '</a></p>
        	</div>
				</div>';

				if ($checked) {

					$this->complete_course($student, $course);
					$email = new ATTEST_LMS_COMPLETE_COURSE_EMAIL($student, $course);
					return $body;
				} else {
					return false;
				}
		}


		public function complete_course($student, $course) {

			$meta = get_user_meta($student, 'attest_enrolled_courses', false);
			if (false != $meta && is_array($meta[0]) && count($meta[0]) > 0) {

				$courses = $meta[0];
				$search = array_search($course, array_column($courses, 'course'));
				if ($search !== false) {

					unset($courses[$search]);
					array_push($courses, array(
						'course' => $course,
						'date' => 0,
					));
				}
			}

			$courses = array_map("unserialize", array_unique(array_map("serialize", $courses)));
			update_user_meta($student, 'attest_enrolled_courses', $courses);
		}


		public function course_check($course, $student) {

			$output = false;

      $meta = get_post_meta($course, 'attest_enrolled_students', false);
      if (false != $meta && count($meta[0]) > 0) {

				$existing = $meta[0];

				if (in_array($student, $existing)) {
					$output = true;
				}
      }

			return $output;
    }
  }
}
