<?php
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Shortcode class for rendering in front end
 */
if ( ! class_exists( 'ATTEST_LMS_COURSES_SHORTCODE' ) ) {

	class ATTEST_LMS_COURSES_SHORTCODE {

		protected $query;
		protected $number_courses;

		public function __construct() {

			$this->number_courses = get_option('attest_number_courses');

			add_shortcode( 'wp_attest_courses', array( $this, 'courses_cb' ) );
		}


		public function courses_cb($atts) {

			$data = shortcode_atts( array(
								'thumbnail' => true,
								'author' => true,
							), $atts );

			return $this->courses_html($data);
		}


		/**
		 * Shortcode Display
		 */
		public function courses_html($data) {

			$query = $this->get_posts();

			$body = '<div class="container">';

        if ($query->have_posts() ) :
          while ( $query->have_posts() ) : $query->the_post();

					$ID = get_the_ID();
					$featured = get_post_meta( $ID, 'attest_course_featured', true);
					$enrollment_data = $this->get_enrollment_data($ID);
					$first_lesson = $this->get_course_first_lesson($ID);

					$body .= '<div class="row attest-course-item course-' . $ID . (($featured == '1' && !is_user_logged_in()) ? ' course-featured' : false) . '">';

						if ($data['thumbnail']) :
							$body .= '<div class="col-md-4 attest-course-thumb" style="background-image: url(\'' . esc_url(get_the_post_thumbnail_url( $ID, 'post-thumbnail' )) . '\');">' .
								( ($featured == '1' && !is_user_logged_in()) ?
									'<span class="badge badge-featured">' . __('FEATURED', 'attest') . '</span>'
								: false ) .
							'</div>';
						endif;

						$body .=
						'<div class="col-md-' . ($data['thumbnail'] ? '8' : '12') . '">
            	<div class="media-body attest-course-item-content">
              	<a class="attest-course-link" href="' . ((false != $enrollment_data['enrolled']) ? esc_url_raw(get_permalink($first_lesson)) : esc_url_raw(get_permalink($ID)) ) . '">
									<h4 class="mt-0 attest-course-title">' . esc_attr(get_the_title()) . '</h4>
								</a>
								<div class="course-meta">';

									if (false != $data['author']) :
										$body .= '<span>' . __('Created by', 'attest') . '&nbsp;' .  get_the_author() . '</span>';
									endif;

									if (!is_user_logged_in()) {
										$body .= $this->get_price_data();
									} else {

										$body .= $enrollment_data['html'];
									}

								$body .=
								'</div>
            	</div>
						</div>
          </div>';

          endwhile;
          wp_reset_postdata();
        endif;

			$body .= $this->navigation();

			$body .= '</div>';

			return $body;
		}


		public function get_price_data() {

			$html = '<p class="attest-course-price"><strong>' . __('FREE', 'attest') . '</strong></p>
			<small>' . __('Requires registration', 'attest') . '</small>';

			return $html;
		}


		public function get_enrollment_data($ID) {

			$enrolled = false;
			$current_user = get_current_user_id();
			$requires = true;
			$text = __('FREE', 'attest');

			$enrolled = get_post_meta($ID, 'attest_enrolled_students', false);
			if (false != $enrolled && count($enrolled) > 0) {

				$existing = $enrolled[0];
				if (in_array($current_user, $existing)) {
					$text = __('Enrolled', 'attest');
					$requires = false;
					$enrolled = true;
				}
			}

			$completed = get_post_meta($ID, 'attest_completed_students', false);
			if (false != $completed && count($completed) > 0) {

				$existing = $completed[0];
				if (in_array($current_user, $existing)) {
					$text = __('Completed', 'attest');
					$requires = false;
				}
			}

			$html = '<p class="attest-course-price"><strong>' . $text . '</strong></p>';
			$html .= ( $requires ? '<small>' . __('Requires registration', 'attest') . '</small>' : false );

			return array(
				'enrolled' => $enrolled,
				'html' => $html,
			);
		}


		public function navigation() {

			$big = 999999999; // need an unlikely integer
			$paged = get_query_var('paged') ? get_query_var('paged') : (get_query_var('page') ? get_query_var('page') : 1);

			$links = paginate_links( array(
				'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format' => '?page=%#%',
				'current' => max( 1, $paged ),
				'total' => $this->query->max_num_pages,
				'prev_next' => false,
				'before_page_number' => '<span class="btn-lg btn-secondary attest-nav-button">',
				'after_page_number' => '</span>',
				'type' => 'array'
			) );

			$nav =
			'<div class="row courses-nav">
				<div class="col-md-12">
				<div class="btn-toolbar justify-content-between" role="toolbar">
  				<div class="btn-group" role="group">';

			$nav .= ((is_array($links) && count($links) > 0 ) ?implode('&nbsp;', $links) : false );

			$nav .= '</div></div></div></div>';

			return $nav;
		}


		public function get_posts() {

			$paged = get_query_var('paged') ? get_query_var('paged') : (get_query_var('page') ? get_query_var('page') : 1);
			$offset = ( $paged - 1 ) * $this->number_courses;

			$args = array(
							'post_type' => 'attest_course',
							'posts_per_page' => $this->number_courses,
							'count_total' => true,
							'orderby' => array(
								'attest_course_featured' => 'DESC'
							),
							'paged' => $paged,
							'offset' =>  $offset,
					);
			$this->query = new WP_Query($args);

			return $this->query;
		}


		public function get_course_first_lesson($course_id) {

      $output = false;

      $meta = get_post_meta($course_id, 'attest_curriculum', false);
      if (false != $meta && count($meta[0]) > 0) {

        $sections = $meta[0];
        $count_section = count($sections);

        $lesson_count = 0;
        if ($count_section > 0) {

					$k = 0;
          foreach ($sections as $section) {

						unset($section['title']);
            $lesson_count += count($section[0]);
						if (count($section) > 0) {

							foreach ($section as $lesson) {

								$lesson_id = ( isset($lesson[0]['lesson_id']) ? $lesson[0]['lesson_id'] : false );

								if ($k == 0) {
									$collect_first_lesson = $lesson_id;
								}

								$k++;
							}
						}
          }
        }

				$output = $collect_first_lesson;
      }

      return $output;
    }
  }
}
